@@ -520,6 +520,7 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
                 default=obj.default,
                 title=obj.title,
                 description=obj.description,
+                is_public=obj.is_public,
             )
             for obj in query.all()
         ]
@@ -536,6 +537,7 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
                 default=api_root.default,
                 title=api_root.title,
                 description=api_root.description,
+                is_public=api_root.is_public,
             )
         else:
             return None
@@ -545,6 +547,7 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
         title: str,
         description: Optional[str] = None,
         default: Optional[bool] = False,
+        is_public: bool = False,
     ) -> entities.ApiRoot:
         """
         Add a new api root.
@@ -552,11 +555,12 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
         :param str title: Title of the new api root
         :param str description: [Optional] Description of the new api root
         :param bool default: [Optional, False] If the new api should be the default
+        :param bool is_public: whether this is a publicly readable API root
 
         :return: The added ApiRoot entity.
         """
         api_root = taxii2models.ApiRoot(
-            title=title, description=description, default=False
+            title=title, description=description, default=default, is_public=is_public
         )
         self.db.session.add(api_root)
         self.db.session.commit()
@@ -567,11 +571,39 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
             default=api_root.default,
             title=api_root.title,
             description=api_root.description,
+            is_public=is_public,
         )
 
+    def _job_and_details_to_entity(
+        self, job: taxii2models.Job, job_details: List[taxii2models.JobDetail]
+    ) -> entities.Job:
+        job_entity = entities.Job(
+            id=job.id,
+            api_root_id=job.api_root_id,
+            status=job.status,
+            request_timestamp=job.request_timestamp,
+            completed_timestamp=job.completed_timestamp,
+            total_count=job.total_count,
+            success_count=job.success_count,
+            failure_count=job.failure_count,
+            pending_count=job.pending_count,
+        )
+        for job_detail in job_details:
+            getattr(job_entity.details, job_detail.status).append(
+                entities.JobDetail(
+                    id=job_detail.id,
+                    job_id=job_detail.job_id,
+                    stix_id=job_detail.stix_id,
+                    version=job_detail.version,
+                    message=job_detail.message,
+                    status=job_detail.status,
+                )
+            )
+        return job_entity
+
     def get_job_and_details(
         self, api_root_id: str, job_id: str
-    ) -> Tuple[Optional[entities.Job], List[entities.JobDetail]]:
+    ) -> Optional[entities.Job]:
         job = (
             self.db.session.query(taxii2models.Job)
             .filter(
@@ -581,7 +613,7 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
             .one_or_none()
         )
         if job is None:
-            return None, []
+            return None
         job_details = (
             self.db.session.query(taxii2models.JobDetail)
             .filter(
@@ -590,26 +622,8 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
             .order_by(taxii2models.JobDetail.stix_id)
             .all()
         )
-        return (
-            entities.Job(
-                id=job.id,
-                api_root_id=job.api_root_id,
-                status=job.status,
-                request_timestamp=job.request_timestamp,
-                completed_timestamp=job.completed_timestamp,
-            ),
-            [
-                entities.JobDetail(
-                    id=job_detail.id,
-                    job_id=job_detail.job_id,
-                    stix_id=job_detail.stix_id,
-                    version=job_detail.version,
-                    message=job_detail.message,
-                    status=job_detail.status,
-                )
-                for job_detail in job_details
-            ],
-        )
+        job_entity = self._job_and_details_to_entity(job, job_details)
+        return job_entity
 
     def job_cleanup(self) -> int:
         """
@@ -949,11 +963,15 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
 
     def add_objects(
         self, api_root_id: str, collection_id: str, objects: List[Dict]
-    ) -> Tuple[entities.Job, List[entities.JobDetail]]:
+    ) -> entities.Job:
         job = taxii2models.Job(
             api_root_id=api_root_id,
             status="pending",
             request_timestamp=datetime.datetime.now(datetime.timezone.utc),
+            total_count=0,
+            success_count=0,
+            failure_count=0,
+            pending_count=0,
         )
         self.db.session.add(job)
         self.db.session.commit()
@@ -999,29 +1017,13 @@ class Taxii2SQLDatabaseAPI(BaseSQLDatabaseAPI, OpenTAXII2PersistenceAPI):
             )
             job_details.append(job_detail)
             self.db.session.add(job_detail)
+            job.total_count += 1
+            job.success_count += 1
         job.status = "complete"
         job.completed_timestamp = datetime.datetime.now(datetime.timezone.utc)
         self.db.session.commit()
-        return (
-            entities.Job(
-                id=job.id,
-                api_root_id=job.api_root_id,
-                status=job.status,
-                request_timestamp=job.request_timestamp,
-                completed_timestamp=job.completed_timestamp,
-            ),
-            [
-                entities.JobDetail(
-                    id=job_detail.id,
-                    job_id=job_detail.job_id,
-                    stix_id=job_detail.stix_id,
-                    version=job_detail.version,
-                    message=job_detail.message,
-                    status=job_detail.status,
-                )
-                for job_detail in job_details
-            ],
-        )
+        job_entity = self._job_and_details_to_entity(job, job_details)
+        return job_entity
 
     def get_object(
         self,
